@@ -1,4 +1,4 @@
-/*$Id: add2list.js,v 1.2 2007/04/13 16:39:44 jwrobel Exp $*/
+/*$Id: add2list.js,v 1.3 2007/09/24 20:06:46 jwrobel Exp $*/
 /* ***** BEGIN LICENSE BLOCK *****
  *  This file is part of Firekeeper.
  *
@@ -113,8 +113,9 @@ function add2listInit()
 
 function createOptions(reg, content)
 {
-	var reg =  "/^" + reg +"$/i";	
 	var reason = "Broken rule. ";
+	reg =  "/^" + reg +"$/i";	
+	
 	if (rule.msg)
 		reason += rule.msg + " ";
 	if (rule.fid)
