@@ -1,4 +1,4 @@
-/*$Id: alert.js,v 1.14 2007/04/13 13:25:10 jwrobel Exp $*/
+/*$Id: alert.js,v 1.17 2007/09/18 20:02:47 jwrobel Exp $*/
 /* ***** BEGIN LICENSE BLOCK *****
  *  This file is part of Firekeeper.
  *
@@ -19,15 +19,18 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  * ***** END LICENSE BLOCK ***** */
 
+var url = null;
 var sentence = null;
 var rule = null;
+var details = null;
 
 function alertInit()
 {	
 	getServices();
-	var url = window.arguments[0];
+	url = window.arguments[0];
 	rule = window.arguments[1];
 	sentence = window.arguments[2];
+	details = window.arguments[3];
 	
 	var urlLabel = document.getElementById('url-label');
 	urlLabel.setAttribute('value', url);
@@ -36,14 +39,19 @@ function alertInit()
 		var msgLabel = document.getElementById('msg-label');
 		msgLabel.setAttribute('value', "*** " + rule.msg + " ***");
 	}
+	if (!sentence){
+		hideElement('action-groupbox');
+		document.title = "Firekeeper log entry";
+	}
 	
 	var count = {};
-	var refnode = document.getElementById("references");	
 	var references = rule.getReferences(count);
 
-	if (count)
-		refnode.setAttribute("hidden", "false");
+	if (count.value){
+		showElement("references");
+	}
 	
+	var refnode = document.getElementById("references");	
 	for(var i = 0; i < count.value; i++){
 		var link = document.createElement("label");
 		var refurl = ""; 
@@ -77,7 +85,8 @@ function alertInit()
 
 function block()
 {
-	sentence.action = sentence.BLOCK; 
+	if (sentence)
+		sentence.action = sentence.BLOCK; 
 	close();
 }
 
@@ -115,3 +124,10 @@ function whitelist(options)
 	sentence.action = sentence.DONT_AUDIT; 
 	close();
 }
+
+function showDetails()
+{
+	var options = "chrome,modal=yes,resizable,centerscreen";
+	window.openDialog("chrome://firekeeper/content/alertdetails.xul",
+			  "_blank", options, rule, url, details); 
+}
