@@ -1,4 +1,4 @@
-/*$Id: fkHttpHandler.h,v 1.14 2007/06/20 19:05:27 jwrobel Exp $*/
+/*$Id: fkHttpHandler.h,v 1.16 2007/08/16 12:06:19 jwrobel Exp $*/
 /* ***** BEGIN LICENSE BLOCK *****
  *  This file is part of Firekeeper.
  *
@@ -35,7 +35,7 @@
 #include "nsIComponentRegistrar.h"
 
 #include "nsIGenericFactory.h"
- 
+
 #include "nsWeakReference.h"
 
 #include "nsInterfaceHashtable.h"
@@ -57,14 +57,25 @@ extern nsDataHashtable<nsISupportsHashKey, fkLoadGroup *> *groupHashTable;
 inline nsIRequest* getRequestProxy(nsIRequest *origRequest)
 {
 	fkHttpChannel *result;
-	if (!requestHashTable->Get(origRequest, &result)){
+	if (!origRequest || !requestHashTable->Get(origRequest, &result)){
 		TRACE("Request not found %08x", origRequest);
 		return nsnull;
 	}
-	TRACE("BUM %08x %08x", origRequest, result);
+	TRACE("Proxy request found %08x %08x", origRequest, result);
 	return result;
 }
 
+inline nsIRequest* tryGetRequestProxy(nsIRequest *origRequest)
+{
+	TRACE("");
+	nsIRequest *result = getRequestProxy(origRequest);
+#ifdef DEBUG
+	if (!result){
+		TRACE("failed to get request proxy");
+	}
+#endif
+	return result ? result : origRequest;
+}
 
 #define FK_HTTPHANDLER_CID \
   {0x03183b3c, 0x1d91, 0x4a35,\
@@ -93,16 +104,16 @@ public:
 	NS_DECL_NSIPROXIEDPROTOCOLHANDLER
 	NS_DECL_NSIHTTPPROTOCOLHANDLER
 	NS_DECL_NSIOBSERVER
-	 
+
 	fkHttpHandler();
 	virtual ~fkHttpHandler();
 	NS_IMETHODIMP init(nsIHttpProtocolHandler *origHttpHandler);
-	
+
 	void enableTracing(PRBool tracingEnabled);
 	PRBool isTracingEnabled();
-	
- private:
-	/*Oryginal handlers that are still responsible for processing 
+
+private:
+	/*Oryginal handlers that are still responsible for processing
 	  traffic, but after Firekeeper checks that it is not dangerous*/
 	nsCOMPtr<nsIProtocolHandler> origHandler;
 	nsCOMPtr<nsIHttpProtocolHandler> origHttpHandler;
@@ -115,11 +126,6 @@ public:
 	*/
 	PRBool tracingEnabled;
 
-	/* These are not supported
-	   and are not implemented*/
-	fkHttpHandler(const fkHttpHandler& x);
-	fkHttpHandler& operator=(const fkHttpHandler& x);
-
 };
 
 #endif
