@@ -1,8 +1,8 @@
-/*$Id: fkRule.cpp,v 1.6 2006/10/02 11:56:20 jwrobel Exp $*/
+/*$Id: fkRule.cpp,v 1.9 2007/09/24 20:06:48 jwrobel Exp $*/
 /* ***** BEGIN LICENSE BLOCK *****
  *  This file is part of Firekeeper.
  *
- *  Copyright (C) 2006 Jan Wrobel <wrobel@blues.ath.cx>
+ *  Copyright (C) 2006,2007 Jan Wrobel <wrobel@blues.ath.cx>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,27 +26,109 @@
 #include "nsMemory.h"
 #include "nsCRT.h"
 
-fkRule::fkRule(const Rule *rule)
+/*TODO: maybe better way than to copy all the fields in the Rule is to
+  make fkRule own the Rule. Ay lease do the map no to duplicate fkRule for
+  the same rule*/
+fkRule::fkRule(): ruleraw(nsnull), action(nsnull), msg(nsnull),
+		  references(nsnull), references_cnt(0), 
+		  fid(0), rev(0)
 {
-	TRACE("constructor %08x", this);
-	this->rule = rule;
+	TRACE("constructor %08x", this);	
+}
+
+NS_IMETHODIMP
+fkRule::Init(const Rule *rule)
+{
+	if (!rule)
+		return NS_ERROR_NULL_POINTER;
+
+	fid = rule->fid;
+	rev = rule->rev;
+	
+	if (rule->ruleraw){
+		ruleraw = nsCRT::strdup(rule->ruleraw);
+		if (!ruleraw)
+			return NS_ERROR_OUT_OF_MEMORY;
+	}
+	
+	if (rule->action){
+		action = nsCRT::strdup(rule->action);
+		if (!action)
+			return NS_ERROR_OUT_OF_MEMORY;
+	}
+	
+	if (rule->msg){
+		msg = nsCRT::strdup(rule->msg);
+		if (!msg)
+			return NS_ERROR_OUT_OF_MEMORY;
+	}
+	
+	references_cnt = rule->references.size();
+	if (references_cnt == 0)
+		return NS_OK;
+	
+	references = (fkRuleReference **)
+		nsMemory::Alloc(sizeof(fkRuleReference *) * references_cnt);
+	if (!references)
+		return NS_ERROR_OUT_OF_MEMORY;
+	
+	list<reference>::const_iterator it = rule->references.begin();
+	for(PRUint32 i = 0; i < references_cnt; ++i, ++it){
+		references[i] = new fkRuleReference();
+		
+		if (!references[i] || NS_FAILED(references[i]->Init(&*it))){
+			for(PRUint32 j = 0; j <= i; j++)
+				if (references[j])
+					NS_RELEASE(references[j]);
+			nsMemory::Free(references);
+			references = nsnull;
+			return NS_ERROR_OUT_OF_MEMORY;
+		}
+		NS_ADDREF(references[i]);		
+	}
+	return NS_OK;
 }
 
 fkRule::~fkRule()
 {
 	TRACE("destructor %08x", this);
+	if (ruleraw)
+		nsMemory::Free(ruleraw);
+	if (action)
+		nsMemory::Free(action);
+	if (msg)
+		nsMemory::Free(msg);
+	if (references){
+		for(PRUint32 j = 0; j < references_cnt; j++)
+			NS_RELEASE(references[j]);
+		nsMemory::Free(references);
+	}
 }
 
 NS_IMPL_ISUPPORTS1(fkRule, fkIRule)
 
+NS_IMETHODIMP fkRule::GetRuleraw(char **aRuleraw)
+{
+	if (!aRuleraw)
+		return NS_ERROR_NULL_POINTER;
+	*aRuleraw = nsnull;
+	
+	if(ruleraw){
+		*aRuleraw = nsCRT::strdup(ruleraw);	
+		if (!*aRuleraw)
+			return NS_ERROR_OUT_OF_MEMORY;
+	}
+	return NS_OK;
+}
+
 NS_IMETHODIMP fkRule::GetAction(char **aAction)
 {
 	if (!aAction)
 		return NS_ERROR_NULL_POINTER;
 	*aAction = nsnull;
 
-	if(rule->action){
-		*aAction = nsCRT::strdup(rule->action);	
+	if(action){
+		*aAction = nsCRT::strdup(action);	
 		if (!*aAction)
 			return NS_ERROR_OUT_OF_MEMORY;
 	}
@@ -60,8 +142,8 @@ NS_IMETHODIMP fkRule::GetMsg(char **aMsg)
 		return NS_ERROR_NULL_POINTER;
 	*aMsg = nsnull;
 
-	if(rule->msg){
-		*aMsg = nsCRT::strdup(rule->msg);	
+	if(msg){
+		*aMsg = nsCRT::strdup(msg);	
 		if (!*aMsg)
 			return NS_ERROR_OUT_OF_MEMORY;
 	}
@@ -69,38 +151,28 @@ NS_IMETHODIMP fkRule::GetMsg(char **aMsg)
 }
 
 
-NS_IMETHODIMP fkRule::GetReferences(PRUint32 *count, fkIRuleReference ***references)
+NS_IMETHODIMP fkRule::GetReferences(PRUint32 *aCount, fkIRuleReference ***aReferences)
 {
-	if (!count || !references)
+	if (!aCount || !aReferences)
 		return NS_ERROR_NULL_POINTER;
-	*count = 0;
-	*references = nsnull;
+	*aCount = 0;
+	*aReferences = nsnull;
 	
-	int size = rule->references.size();
-	if (size == 0)
+	if (references_cnt == 0)
 		return NS_OK;
 	
 	fkIRuleReference **out = (fkIRuleReference **)
-		nsMemory::Alloc(sizeof(fkIRuleReference *) * size);
+		nsMemory::Alloc(sizeof(fkIRuleReference *) * references_cnt);
 	if (!out)
 		return NS_ERROR_OUT_OF_MEMORY;
 	
-	list<reference>::const_iterator it = rule->references.begin();
-	
-	for(int i = 0; i < size; ++i, ++it){
-		out[i] = new fkRuleReference(&*it);
-		
-		if (!out[i]){
-			for(int j = 0; j < i; j++)
-				NS_RELEASE(out[j]);
-			nsMemory::Free(out);
-			return NS_ERROR_OUT_OF_MEMORY;
-		}
+	for(PRUint32 i = 0; i < references_cnt; ++i){
+		out[i] = references[i];
 		NS_ADDREF(out[i]);		
 	}
 	
-	*references = out;
-	*count = size;
+	*aReferences = out;
+	*aCount = references_cnt;
 	return NS_OK;
 }
 
@@ -109,7 +181,7 @@ NS_IMETHODIMP fkRule::GetFid(PRUint32 *aFid)
 {	
 	if (!aFid)
 		return NS_ERROR_NULL_POINTER;
-	*aFid = rule->fid;
+	*aFid = fid;
 	return NS_OK;
 }
 
@@ -118,7 +190,7 @@ NS_IMETHODIMP fkRule::GetRev(PRUint32 *aRev)
 {
 	if (!aRev)
 		return NS_ERROR_NULL_POINTER;
-	*aRev = rule->rev;
+	*aRev = rev;
 	return NS_OK;
 }
 
