@@ -1,4 +1,4 @@
-/*$Id: fkRule.h,v 1.6 2006/11/04 21:09:25 jwrobel Exp $*/
+/*$Id: fkRule.h,v 1.7 2007/09/17 22:18:56 jwrobel Exp $*/
 /* ***** BEGIN LICENSE BLOCK *****
  *  This file is part of Firekeeper.
  *
@@ -23,6 +23,8 @@
 #define FKRULE_H
 
 #include "fkIRule.h"
+#include "fkIRuleReference.h"
+#include "fkRuleReference.h"
 #include "Rule.h"
 
 /*
@@ -34,10 +36,17 @@ class fkRule : public fkIRule
 	NS_DECL_ISUPPORTS
         NS_DECL_FKIRULE
 
-        fkRule(const Rule *);
+        NS_IMETHODIMP Init(const Rule *rule);
+        fkRule();
 	virtual ~fkRule();
  private:
-	const Rule *rule;
+	char *ruleraw;
+	char *action;
+	char *msg;
+	fkRuleReference **references;
+	PRUint32 references_cnt;
+	PRUint32 fid;
+	PRUint32 rev;
 
 };
 
