@@ -1,4 +1,4 @@
-/*$Id: fkStreamListener.cpp,v 1.24 2007/08/16 12:06:19 jwrobel Exp $*/
+/*$Id: fkStreamListener.cpp,v 1.28 2007/09/24 20:06:48 jwrobel Exp $*/
 
 /* ***** BEGIN LICENSE BLOCK *****
  *  This file is part of Firekeeper.
@@ -95,24 +95,28 @@ fkStreamListener::fkStreamListener(nsIStreamListener *origListener,
 	this->sentence = sentence;
 	this->connRules = connRules;
 	this->channel = channel;
-	NS_ADDREF(this->channel);
+	NS_ADDREF(this->channel);	
 
+	drawFlushPoint();
+	drawNoFlushPoint();
+}
+
+NS_IMETHODIMP 
+fkStreamListener::Init()
+{
 	body = (char *)nsMemory::Alloc(body_max);
 	if (body == nsnull){
 		body_max = headers_max = 0;
-		return;
+		return NS_ERROR_OUT_OF_MEMORY;
 	}
 
 	headers = (char *)nsMemory::Alloc(headers_max);
 	if (headers == nsnull){
 		body_max = headers_max = 0;
-		nsMemory::Free(body);
-		body = nsnull;
-		return;
+		return NS_ERROR_OUT_OF_MEMORY;
 	}
-
-	drawFlushPoint();
-	drawNoFlushPoint();
+	
+	return NS_OK;
 }
 
 fkStreamListener::~fkStreamListener()
@@ -215,13 +219,27 @@ fkStreamListener::checkBody()
 	list<const Rule *> match = connRules->checkBody(body, body_len);
 	list<const Rule *>::iterator it;
 	for(it = match.begin(); it != match.end(); ++it){
-		fkRule *rule_raw = new fkRule(*it);
+		TRACE("calling judge %08x hmm", &*fkJudge);
+		fkRule *rule_raw = new fkRule();
 		if (!rule_raw){
 			return NS_ERROR_OUT_OF_MEMORY;
 		}
-		nsCOMPtr<fkIRule>
-			rule(do_QueryInterface(rule_raw));
-		fkJudge->Judge(getURL(), rule, sentence);
+		if (NS_FAILED(rule_raw->Init(*it))){
+			delete rule_raw;
+			return NS_ERROR_OUT_OF_MEMORY;
+		}
+		nsCOMPtr<fkIRule> rule = do_QueryInterface(rule_raw);
+		
+		fkResponseDetails *details_raw = new fkResponseDetails(headers, headers_len,
+								       body, body_len, offset);
+		if (!details_raw){
+			return NS_ERROR_OUT_OF_MEMORY;
+		}
+		nsCOMPtr<fkIResponseDetails> details = do_QueryInterface(details_raw);
+
+		nsresult rv = fkJudge->Judge(getURL(), rule, sentence, details);
+		//FK_ASSERT(!NS_FAILED(rv));
+		
 		int action;
 		sentence->GetAction(&action);
 		TRACE("action = %d", action);
@@ -370,7 +388,7 @@ fkStreamListener::OnDataAvailable(nsIRequest *request, nsISupports *ctxt,
 						     off, count);
 	}
 	FK_ASSERT(action != sentence->BLOCK);
-
+	
 	if (expandBuf(&body, count, body_len, body_max) != NS_OK){
 		TRACE("Out of memory, can't expand buffer");
 		return NS_ERROR_OUT_OF_MEMORY;
@@ -380,7 +398,7 @@ fkStreamListener::OnDataAvailable(nsIRequest *request, nsISupports *ctxt,
 	input->Read(body + body_len, count, &res);
 	FK_ASSERT(res == count);
 	body_len += count;
-
+	
 	/*
 	  Not whole body fragment is filled.
 	 */
@@ -421,24 +439,37 @@ fkStreamListener::OnStartRequest(nsIRequest *request, nsISupports* acontext)
 		return rv;
 	}
 	debugNoHeaders = false;
-	rv = headers_append("", 1);
-	if (NS_FAILED(rv)){
-		return rv;
-	}
 
-	TRACE("headers:\n %s", headers);
+	/*(rv = headers_append("", 1);
+		 if (NS_FAILED(rv)){
+		 return rv;
+			 }
+		 TRACE("headers:\n %s", headers);*/
 
 	list<const Rule *> match = connRules->checkHeaders(headers,
-							   strlen(headers));
+							   headers_len);
 	list<const Rule *>::iterator it;
 	for(it = match.begin(); it != match.end(); ++it){
-		fkRule *rule_raw = new fkRule(*it);
+		TRACE("calling judge");
+		fkRule *rule_raw = new fkRule();
 		if (!rule_raw){
 			return NS_ERROR_OUT_OF_MEMORY;
 		}
+		if (NS_FAILED(rv = rule_raw->Init(*it))){
+			delete rule_raw;
+			return NS_ERROR_OUT_OF_MEMORY;
+		}
 		nsCOMPtr<fkIRule>
 			rule(do_QueryInterface(rule_raw));
-		fkJudge->Judge(getURL(), rule, sentence);
+
+		fkResponseDetails *details_raw = new fkResponseDetails(headers, headers_len,
+								       nsnull, 0, 0);
+		if (!details_raw){
+			return NS_ERROR_OUT_OF_MEMORY;
+		}
+		nsCOMPtr<fkIResponseDetails> details = do_QueryInterface(details_raw);
+		
+		fkJudge->Judge(getURL(), rule, sentence, details_raw);
 		int action;
 		sentence->GetAction(&action);
 		TRACE("action = %d", action);
