@@ -1,4 +1,4 @@
-/*$Id: fkStreamListener.h,v 1.17 2007/07/22 20:05:21 jwrobel Exp $*/
+/*$Id: fkStreamListener.h,v 1.18 2007/09/05 21:48:53 jwrobel Exp $*/
 
 /* ***** BEGIN LICENSE BLOCK *****
  *  This file is part of Firekeeper.
@@ -26,6 +26,8 @@
 #include "fkHttpChannel.h"
 #include "fkSentence.h"
 #include "fkIStreamListenerProxy.h"
+#include "fkResponseDetails.h"
+
 #include "nsISupports.h"
 #include "nsISupportsUtils.h"
 #include "nsWeakReference.h"
@@ -52,12 +54,13 @@ public:
 			 fkHttpChannel *channel, fkISentence *sentence, 
 			 ActiveRuleSet *connRules);
 	virtual ~fkStreamListener();
+	NS_IMETHODIMP Init();
 
 	NS_DECL_ISUPPORTS
         NS_DECL_NSISTREAMLISTENER
         NS_DECL_NSIREQUESTOBSERVER
         NS_DECL_NSIHTTPHEADERVISITOR
-        NS_DECL_FKISTREAMLISTENERPROXY
+        NS_DECL_FKISTREAMLISTENERPROXY    		
 
 private:
 	nsCOMPtr<nsIStreamListener> origListener;
@@ -72,7 +75,7 @@ private:
 	NS_IMETHODIMP headers_append(const char *src, PRUint32 len);
 	NS_IMETHODIMP expandBuf(char **buf, PRUint32 len, PRUint32 end, 
 				PRUint32 &max_size);
-	
+
 	void drawFlushPoint();
 	void drawNoFlushPoint();
 	const char* getURL();
@@ -91,6 +94,7 @@ private:
 	PRUint32 body_max, headers_max;
 	PRUint32 offset;
 	nsCOMPtr<fkISentence> sentence;
+
 	fkHttpChannel *channel;	
 	ActiveRuleSet *connRules;
 	
