@@ -1,8 +1,8 @@
-/*$Id: ActiveRuleSet.cpp,v 1.6 2007/02/13 00:11:14 jwrobel Exp $*/
+/*$Id: ActiveRuleSet.cpp,v 1.7 2007/09/17 22:18:56 jwrobel Exp $*/
 /* ***** BEGIN LICENSE BLOCK *****
  *  This file is part of Firekeeper.
  *
- *  Copyright (C) 2006 Jan Wrobel <wrobel@blues.ath.cx>
+ *  Copyright (C) 2006,2007 Jan Wrobel <wrobel@blues.ath.cx>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -256,7 +256,7 @@ ActiveRuleSet::checkHeadersSet(set<Rule *> &rules, list<const Rule *> &result)
 		const Rule *rule = *it;
 
 		for(it2 = rule->headersREs.begin(); it2 != rule->headersREs.end(); ++it2){
-			TRACE("Matching %s against %s", it2->pattern, headers);
+			TRACE("Matching %s against headers", it2->pattern);
 			if (!match(*it2, headers, headerslen)){
 				TRACE("not matched");				
 				to_erase.push_front(it);
@@ -305,7 +305,7 @@ ActiveRuleSet::checkBodySet(set<Rule *> &rules, const char *body, int bodylen,
 		    ++it2){
 			if (bodyMatchedREs.find(&*it2) != bodyMatchedREs.end())
 				continue;
-			TRACE("Matching %s against body", it2->pattern, body);
+			TRACE("Matching %s against body", it2->pattern);
 			if (!match(*it2, body, bodylen)){
 				TRACE("not matched");
 				matched = false;
@@ -380,7 +380,11 @@ list<const Rule*>
 ActiveRuleSet::checkHeaders(const char *headers_arg, int headerslen_arg)
 {
 	list<const Rule *> result;
-	this->headers = strdup(headers_arg);
+	this->headers = (char *)malloc(headerslen_arg);
+	if (!this->headers)
+		//TODO: report error
+		return result;
+	memcpy(this->headers, headers_arg, headerslen_arg);
 	this->headerslen = headerslen_arg;
 	
 	if (rulesVersion < rules->getRulesVersion()){
